# sweetheart.py
a supercharged heart for building incredible full-stacked webapps at the speedlight

## Introduction

Since Ubuntu20.04 can be installed as a usual softwares within Windows10, it provides an incredible way for any organization to develop, administrate and deploy **powerfull responsive webapps** on its own local network including high capabilities of integration with the already existing tools like databases, ms-excel, sap...

The sweetheart framework propose a simple and efficient approach to do it in a python/html/css centric way leading you to the best components and coding practices. Due to the current place of the python language regarding to calculations and AI, this makes sweetheart a fast and ideal toolkit for evoluting to the **Industry4.0** precepts.

### The highest quality components that can be adopted by newbies

- easy to learn, easy to use
- full documentation provided
- built-in reponsive user interfaces
- quick and clean prototyping
- quick and clean deployement
- ready for maintenable great code quality
- **ready for datacenters, big-data and ai**
- ready for inovation and creativity

### A supercharged basis available for the non-expert hands

- provided database server: [**MongoDB**](https://www.mongodb.com/)
- provided asynchronous webserver: [Uvicorn](https://www.uvicorn.org/)
- provided optionnal webserver: [CherryPy](https://cherrypy.org/)
- responsive user interfaces: [Html](https://www.w3schools.com/)
- backend language: [Python3](https://www.python.org/)
- frontend language: [Typescript](https://www.typescriptlang.org/)
- provided libs for going fast: [**Knacss**](https://www.knacss.com/), W3css
- provided libs for high-level featuring: Bootstrap4, [**Vue.js**](https://vuejs.org/)
- all others nice things you wish using apt, pip and npm

start now using same raw materials of gafam and go farer ahead !

## Code examples

### your first standalone webpage conroller

```python
import sweet

def welcome():
    """render a welcome message"""
    return sweet.html()

sweet.quickstart(welcome)
```

### your first *sweet* html webpage

``` html
% rebase("sweet.HTML")

<div class="txtcenter">
    <h1>Welcome!</h1>
    <p>get coding full power at the speedlight</p>
</div>
```
